@@ -60,6 +60,7 @@ def process_full_apt_cache(cache):
 
     for key in keys:
         name = apt_cache[key].name
+        pkg = apt_cache[key]
 
         if name.startswith("lib") and not name.startswith(("libreoffice", "librecad", "libk3b7", "libimage-exiftool-perl")):
             continue
@@ -87,8 +88,12 @@ def process_full_apt_cache(cache):
             continue
         if ":" in name and name.split(":")[0] in keys:
             continue
-
-        pkg = apt_cache[key]
+        try:
+            if "transitional" in pkg.candidate.summary.lower():
+                continue
+        except Exception as e:
+            print(e)
+            # pass
 
         pkg_hash = make_pkg_hash(pkg)
 
